==> opuscodium-odoo-1.2.0.tar.gz: opuscodium-odoo-1.2.0/spec/acceptance/odoo_spec.rb <==
require 'spec_helper_acceptance'

def odoo_supported_versions
  {
    'Debian' => {
      '9'  => ['11.0', '12.0', '13.0', '14.0'],
      '10' => ['11.0', '12.0', '13.0', '14.0'],
    },
    'Ubuntu' => {
      '16.04' => ['10.0', '11.0', '12.0', '13.0', '14.0'],
      '18.04' => ['11.0', '12.0', '13.0', '14.0'],
      '20.04' => ['11.0', '12.0', '13.0', '14.0'],
    },
  }[fact('os.name')][fact('os.release.major')]
end

describe 'odoo class' do
  ['10.0', '11.0', '12.0', '13.0'].each do |version|
    context "when using odoo #{version}" do
      let(:version) { version }

      if odoo_supported_versions.include?(version)
        it 'works idempotently with no errors' do
          # FIXME: We should not tweak anything here, the odoo class should be self-contained
          pp = <<~MANIFEST
            if $facts.get('os.name') == 'debian' {
              class { 'apt::backports':
              }
            }
            if $facts.get('os.name') == 'ubuntu' {
              apt::source { 'ubuntu-universe':
                location => 'http://archive.ubuntu.com/ubuntu',
                repos    => 'universe',
              }
            }

            if '#{version}' == '10.0' {
              package { 'python-pip':
                ensure => installed,
              }
            } else {
              package { 'python3-pip':
                ensure => installed,
              }
            }

            class { 'odoo':
              version => '#{version}'
            }

            Class['apt::update']
            -> Class['odoo::dependencies']
          MANIFEST

          apply_manifest(pp, catch_failures: true)
          apply_manifest(pp, catch_changes: true)
        end
      end
    end
  end
end

==> opuscodium-odoo-2.0.1.tar.gz: opuscodium-odoo-2.0.1/spec/acceptance/odoo_spec.rb <==
require 'spec_helper_acceptance'

def odoo_supported_versions
  {
    'Debian' => {
      '9'  => ['11.0', '12.0', '13.0', '14.0'],
      '10' => ['11.0', '12.0', '13.0', '14.0'],
      '11' => ['system'],
    },
    'Ubuntu' => {
      '18.04' => ['11.0', '12.0', '13.0', '14.0'],
      '20.04' => ['11.0', '12.0', '13.0', '14.0'],
    },
  }[fact('os.name')][fact('os.release.major')]
end

describe 'odoo class' do
  odoo_supported_versions.each do |version|
    context "when using odoo version=#{version.inspect}" do
      let(:version) { version }

      if version == 'system'
        it 'works idempotently with no errors' do
          pp = <<~MANIFEST
            class { 'apt':
              purge => {
                'sources.list.d' => true,
              },
            }

            class { 'odoo':
              version => '#{version}'
            }
          MANIFEST

          apply_manifest(pp, catch_failures: true)
          apply_manifest(pp, catch_changes: true)
        end
      else
        it 'works idempotently with no errors' do
          # FIXME: We should not tweak anything here, the odoo class should be self-contained
          pp = <<~MANIFEST
            class { 'apt':
              purge => {
                'sources.list.d' => true,
              },
            }

            if $facts.get('os.name') == 'debian' {
              class { 'apt::backports':
              }
            }
            if $facts.get('os.name') == 'ubuntu' {
              apt::source { 'ubuntu-universe':
                location => 'http://archive.ubuntu.com/ubuntu',
                repos    => 'universe',
              }
            }

            if '#{version}' == '10.0' {
              package { 'python-pip':
                ensure => installed,
              }
            } else {
              package { 'python3-pip':
                ensure => installed,
              }
            }

            class { 'odoo':
              version => '#{version}'
            }

            Class['apt::update']
            -> Class['odoo::dependencies']
          MANIFEST

          apply_manifest(pp, catch_failures: true)
          apply_manifest(pp, catch_changes: true)
        end
      end
    end
  end
end
